<?php
/**
  * The template for displaying comments.
  *
  * The area of the page that contains both current comments
  * and the comment form.
  *
  * @package twinkle
  */


/**
  * If the current post is protected by a password and
  * the visitor has not yet entered the password we will
  * return early without loading the comments.
  */
if ( post_password_required() ) {
  return;
}
?>

<div class="comments-area-wrapper boxed">
    <div class="comments-area">

    <?php if ( have_comments() ) : ?>
        <h2 class="comments-title">
          <?php
            $comments_number = get_comments_number();
            if ( '1' === $comments_number ) {
              /* translators: %s: post title */
              printf(esc_html( _x( 'One Comment', 'comments title', 'twinkle' )), get_the_title() );
            } else {
              printf(
                /* translators: 1: number of comments, 2: post title */
                esc_html( _nx(
                  '%1$s Comment',
                  '%1$s Comments',
                  $comments_number,
                  'comments title',
                  'twinkle'
                )),
                esc_html(number_format_i18n( $comments_number )),
                get_the_title()
              );
            }
            ?>
        </h2>

        <?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through ?>
        <nav class="comment-navigation clearfix" role="navigation">
          <div class="nav-previous"><?php previous_comments_link( __( '&larr; Older Comments', 'twinkle' ) ); ?></div>
          <div class="nav-next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'twinkle' ) ); ?></div>
        </nav>
        <?php endif; ?>

        <ol class="comment-list">
          <?php
            wp_list_comments( array(
              'style'      => 'ul',
              'short_ping' => true,
              'avatar_size' => 64,
            ) );
          
          ?>
        </ol>

        <?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through ?>
        <nav class="comment-navigation clearfix" role="navigation">
          <div class="nav-previous"><?php previous_comments_link( __( '&larr; Older Comments', 'twinkle' ) ); ?></div>
          <div class="nav-next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'twinkle' ) ); ?></div>
        </nav>
        <?php endif; ?>

      <?php endif; ?>

      <?php
        if ( ! comments_open() && '0' != get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
      ?>
        <p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'twinkle' ); ?></p>
    <?php endif; ?>

    <?php

    $commenter = wp_get_current_commenter();
    $req = get_option( 'require_name_email' );
    $aria_req = ( $req ? " aria-required='true'" : '' );

    $comment_args = array(

      'fields' => apply_filters( 'comment_form_default_fields', array(

        'author' => '<div class="comment-form-author">' . '<label for="author">' . __( 'Name', 'twinkle' ) . '</label> ' . ( $req ? '<span class="required-sign">*</span>' : '' ) .

                '<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' /></div>',

        'email'  => '<div class="comment-form-email">' .

                '<label for="email">' . __( 'Email', 'twinkle' ) . '</label> ' . ( $req ? '<span class="required-sign">*</span>' : '' ) .

                '<input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' />'.'</div>',

        'url'    => '<div class="comment-form-url">' .

                '<label for="url">' . __( 'Website', 'twinkle' ) . '</label> ' .

                '<input id="url" name="url" type="text" value="' . esc_attr(  $commenter['comment_author_url'] ) . '" size="30" />'.'</div>',
      )
    ),

    'comment_field' => '<div class="comment">' .

            '<label for="comment">' . __( 'Comment', 'twinkle' ) . '</label>' .

            '<textarea id="comment" name="comment" cols="45" rows="8" aria-required="true"></textarea>' .

            '</div>',

    'comment_notes_after' => '',

    );

    comment_form($comment_args); ?>

    </div>
</div>